@@ -44,7 +44,8 @@ enum CodeCompletionOpts {
 	CC_DISABLE_AUTO_PARSING       = 0x00000800,
 	CC_MARK_TAGS_FILES_IN_BOLD    = 0x00001000,
 	CC_USE_FULL_RETAGGING         = 0x00002000,
-	CC_RETAG_WORKSPACE_ON_STARTUP = 0x00004000
+	CC_RETAG_WORKSPACE_ON_STARTUP = 0x00004000,
+	CC_ACCURATE_SCOPE_RESOLVING   = 0x00008000
 };
 
 enum CodeCompletionColourOpts {
