@@ -40,10 +40,6 @@ private:	// Methods
 	bool CheckRevision(const wxString &fileName);
 	bool CheckSingularity(const wxCmdLineParser &parser, const wxString &curdir);
 
-#if defined (__WXGTK__)
-  bool LocateConfPath(wxString& installPath);
-#endif
-
 #ifdef __WXMSW__	
 	HINSTANCE m_handler;
 #endif
