@@ -31,141 +31,45 @@
 #include "findresultstab.h"
 #include "replaceinfilespanel.h"
 
-
-BEGIN_EVENT_TABLE(FindInFilesDialog, wxDialog)
-    EVT_CLOSE(FindInFilesDialog::OnClose)
-    EVT_CHAR_HOOK(FindInFilesDialog::OnCharEvent)
-END_EVENT_TABLE()
-
-FindInFilesDialog::FindInFilesDialog(wxWindow* parent, wxWindowID id, const FindReplaceData& data, size_t numpages)
-    : wxDialog(parent, id, wxT("Find In Files"), wxDefaultPosition, wxSize(450, 200))
-    , m_data(data)
+FindInFilesDialog::FindInFilesDialog(wxWindow* parent, wxWindowID id, const FindReplaceData& data)
+: FindInFilesDialogBase(parent, id)
+, m_data(data)
 {
-	CreateGUIControls(numpages);
-	ConnectEvents();
-
-	GetSizer()->Fit(this);
-	GetSizer()->SetMinSize(wxSize(600, 300));
-	GetSizer()->SetSizeHints(this);
-}
-
-FindInFilesDialog::~FindInFilesDialog()
-{
-}
-
-void FindInFilesDialog::CreateGUIControls(size_t numpages)
-{
-	wxBoxSizer *btnSizer = new wxBoxSizer(wxHORIZONTAL);
-	wxBoxSizer *mainSizer = new wxBoxSizer(wxVERTICAL);
-	SetSizer(mainSizer);
-
-	wxStaticText* itemStaticText;
-	itemStaticText = new wxStaticText( this, wxID_STATIC, _("Find What:"), wxDefaultPosition, wxDefaultSize, wxALIGN_LEFT );
-	mainSizer->Add(itemStaticText, 0, wxEXPAND | wxTOP | wxLEFT | wxRIGHT, 5 );
-
-	m_findString = new wxComboBox( this, wxID_ANY, wxEmptyString, wxDefaultPosition, wxSize(200, -1));
-	m_findString->Clear();
-	m_findString->Append(m_data.GetFindStringArr());
-	m_findString->SetValue(m_data.GetFindString());
-	mainSizer->Add(m_findString, 0, wxALL | wxEXPAND, 5 );
-
-	itemStaticText = new wxStaticText( this, wxID_STATIC, _("Look In:"), wxDefaultPosition, wxDefaultSize, wxALIGN_LEFT );
-	mainSizer->Add(itemStaticText, 0, wxEXPAND | wxTOP | wxLEFT | wxRIGHT, 5 );
-
-	m_dirPicker = new DirPicker(this, wxID_ANY, wxT("..."), wxEmptyString, wxT("Select a folder:"), wxDefaultPosition, wxDefaultSize, wxDP_USE_COMBOBOX);
-	mainSizer->Add(m_dirPicker, 0, wxEXPAND | wxALL, 5);
-
+	// DirPicker values
 	wxArrayString choices;
 	choices.Add(SEARCH_IN_PROJECT);
 	choices.Add(SEARCH_IN_WORKSPACE);
 	choices.Add(SEARCH_IN_CURR_FILE_PROJECT);
-
-	for(size_t i=0; i<m_data.GetSearchPaths().GetCount(); i++){
+	for (size_t i = 0; i < m_data.GetSearchPaths().GetCount(); ++i) {
 		choices.Add(m_data.GetSearchPaths().Item(i));
 	}
-
 	m_dirPicker->SetValues(choices, 1);
 
-	// Add the options
-	wxStaticBoxSizer *sz = new wxStaticBoxSizer(wxVERTICAL, this, wxT("Options:"));
-	mainSizer->Add(sz, 1, wxEXPAND | wxALL, 5);
+	// Search for
+	m_findString->Clear();
+	m_findString->Append(m_data.GetFindStringArr());
+	m_findString->SetValue(m_data.GetFindString());
 
-	m_matchCase = new wxCheckBox(this, wxID_ANY, wxT("&Match case"));
-	m_matchCase->SetValue(m_data.GetFlags() & wxFRD_MATCHCASE ? true : false);
-	sz->Add(m_matchCase, 1, wxALL | wxEXPAND, 5 );
+	m_fileTypes->SetSelection(0);
 
-	m_matchWholeWord = new wxCheckBox(this, wxID_ANY, wxT("Match &whole word"));
-	m_matchWholeWord->SetValue(m_data.GetFlags() & wxFRD_MATCHWHOLEWORD ? true : false);
-	sz->Add(m_matchWholeWord, 1, wxALL | wxEXPAND, 5 );
+	Connect(wxEVT_CHAR_HOOK, wxCharEventHandler(FindInFilesDialog::OnCharEvent));
 
-	m_regualrExpression = new wxCheckBox(this, wxID_ANY, wxT("Regular &expression"));
-	m_regualrExpression->SetValue(m_data.GetFlags() & wxFRD_REGULAREXPRESSION ? true : false);
-	sz->Add(m_regualrExpression, 1, wxALL | wxEXPAND, 5 );
+	m_matchCase->SetValue(m_data.GetFlags() & wxFRD_MATCHCASE);
+	m_matchWholeWord->SetValue(m_data.GetFlags() & wxFRD_MATCHWHOLEWORD);
+	m_regualrExpression->SetValue(m_data.GetFlags() & wxFRD_REGULAREXPRESSION);
+	m_fontEncoding->SetValue(m_data.GetFlags() & wxFRD_USEFONTENCODING);
+	m_printScope->SetValue(m_data.GetFlags() & wxFRD_DISPLAYSCOPE);
+	m_checkBoxSaveFilesBeforeSearching->SetValue(m_data.GetFlags() & wxFRD_SAVE_BEFORE_SEARCH);
 
-	m_fontEncoding = new wxCheckBox(this, wxID_ANY, wxT("Use the editor's font encoding (when left unchecked encoding is set to UTF8)"));
-	m_fontEncoding->SetValue(m_data.GetFlags() & wxFRD_USEFONTENCODING ? true : false);
-	sz->Add(m_fontEncoding, 1, wxALL | wxEXPAND, 5 );
+	GetSizer()->Fit(this);
+	//GetSizer()->SetMinSize(wxSize(600, 300));
+	//GetSizer()->SetSizeHints(this);
 
-    m_printScope = new wxCheckBox(this, wxID_ANY, wxT("Display C++ scope (class/function) in result match"));
-    m_printScope->SetValue(m_data.GetFlags() & wxFRD_DISPLAYSCOPE ? true : false);
-    sz->Add(m_printScope, 1, wxALL | wxEXPAND, 5 );
-
-	itemStaticText = new wxStaticText( this, wxID_STATIC, wxT("Look at these file &types:"), wxDefaultPosition, wxDefaultSize, wxALIGN_LEFT );
-	sz->Add(itemStaticText, 0, wxEXPAND | wxTOP | wxLEFT | wxRIGHT, 5 );
-
-	wxString options [] = {
-			wxT("*.c;*.cpp;*.cxx;*.cc;*.h;*.hpp;*.hxx;*.hh;*.inl;*.inc"),
-			wxT("*.*") };
-
-	m_fileTypes = new wxComboBox(this,
-								wxID_ANY,
-								options[0],
-								wxDefaultPosition, wxDefaultSize,
-								2, options, wxCB_DROPDOWN);
-	sz->Add(m_fileTypes, 0, wxEXPAND | wxALL, 5);
-
-	itemStaticText = new wxStaticText( this, wxID_STATIC, wxT("Display search results in tab:"), wxDefaultPosition, wxDefaultSize, wxALIGN_LEFT );
-	sz->Add(itemStaticText, 0, wxEXPAND | wxTOP | wxLEFT | wxRIGHT, 5 );
-
-	wxArrayString tabs;
-    for (size_t n = 1; n <= numpages; n++) {
-        tabs.Add(wxString::Format(wxT("Find Results %u"), n));
-    }
-	m_searchResultsTab = new wxChoice( this, wxID_ANY, wxDefaultPosition, wxDefaultSize, tabs);
-	sz->Add(m_searchResultsTab, 0, wxEXPAND | wxALL, 5 );
-	m_searchResultsTab->SetSelection(0);
-
-	// Add the buttons
-	m_find = new wxButton(this, wxID_ANY, wxT("&Find"));
-	btnSizer->Add(m_find, 1, wxALL | wxEXPAND, 5 );
-
-	m_replaceAll = new wxButton(this, wxID_ANY, wxT("Find &Replace Candidates"));
-	btnSizer->Add(m_replaceAll, 1, wxALL | wxEXPAND, 5 );
-
-	m_stop = new wxButton(this, wxID_ANY, wxT("&Stop Search"));
-	btnSizer->Add(m_stop, 1, wxALL | wxEXPAND, 5 );
-
-	m_cancel = new wxButton(this, wxID_ANY, wxT("Close"));
-	btnSizer->Add(m_cancel, 1, wxALL | wxEXPAND, 5 );
-
-	mainSizer->Add(new wxStaticLine(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxLI_HORIZONTAL), 0, wxEXPAND );
-	mainSizer->Add(btnSizer, 0, wxEXPAND|wxALL, 5);
+	Centre();
 }
 
-void FindInFilesDialog::ConnectEvents()
+FindInFilesDialog::~FindInFilesDialog()
 {
-	// Connect buttons
-	m_find->Connect(wxID_ANY, wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(FindInFilesDialog::OnClick), NULL, this);
-	m_replaceAll->Connect(wxID_ANY, wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(FindInFilesDialog::OnClick), NULL, this);
-	m_cancel->Connect(wxID_ANY, wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(FindInFilesDialog::OnClick), NULL, this);
-	m_stop->Connect(wxID_ANY, wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(FindInFilesDialog::OnClick), NULL, this);
-
-	// connect options
-	m_matchCase->Connect(wxID_ANY, wxEVT_COMMAND_CHECKBOX_CLICKED , wxCommandEventHandler(FindInFilesDialog::OnClick), NULL, this);
-	m_matchWholeWord->Connect(wxID_ANY, wxEVT_COMMAND_CHECKBOX_CLICKED , wxCommandEventHandler(FindInFilesDialog::OnClick), NULL, this);
-	m_regualrExpression->Connect(wxID_ANY, wxEVT_COMMAND_CHECKBOX_CLICKED , wxCommandEventHandler(FindInFilesDialog::OnClick), NULL, this);
-	m_fontEncoding->Connect(wxID_ANY, wxEVT_COMMAND_CHECKBOX_CLICKED , wxCommandEventHandler(FindInFilesDialog::OnClick), NULL, this);
-    m_printScope->Connect(wxID_ANY, wxEVT_COMMAND_CHECKBOX_CLICKED , wxCommandEventHandler(FindInFilesDialog::OnClick), NULL, this);
 }
 
 void FindInFilesDialog::SetSearchData(const SearchData &data)
@@ -184,11 +88,18 @@ void FindInFilesDialog::SetSearchData(const SearchData &data)
     m_matchCase->SetValue(data.IsMatchCase());
     m_matchWholeWord->SetValue(data.IsMatchWholeWord());
     m_regualrExpression->SetValue(data.IsRegularExpression());
-    m_dirPicker->SetPath(data.GetRootDir());
     m_fontEncoding->SetValue(data.UseEditorFontConfig());
     m_printScope->SetValue(data.GetDisplayScope());
     m_fileTypes->SetValue(data.GetExtensions());
-    m_searchResultsTab->SetSelection(data.GetOutputTab());
+
+	m_listPaths->Clear();
+	const wxArrayString& rootDirs = data.GetRootDirs();
+	for (size_t i = 0; i < rootDirs.Count(); ++i) {
+		m_listPaths->Append(rootDirs.Item(i));
+	}
+	if (rootDirs.IsEmpty() == false) {
+		m_dirPicker->SetPath(rootDirs.Item(0));
+	}
 }
 
 void FindInFilesDialog::SetRootDir(const wxString &rootDir)
@@ -200,6 +111,8 @@ void FindInFilesDialog::DoSearchReplace()
 {
 	SearchData data = DoGetSearchData();
     data.SetOwner(Frame::Get()->GetOutputPane()->GetReplaceResultsTab());
+
+	DoSaveOpenFiles();
 	SearchThreadST::Get()->PerformSearch(data);
 
 	DoSaveSearchPaths();
@@ -209,7 +122,10 @@ void FindInFilesDialog::DoSearchReplace()
 void FindInFilesDialog::DoSearch()
 {
 	SearchData data = DoGetSearchData();
-    data.SetOwner(Frame::Get()->GetOutputPane()->GetFindResultsTab());
+	data.SetOwner(Frame::Get()->GetOutputPane()->GetFindResultsTab());
+
+	// check to see if we require to save the files
+	DoSaveOpenFiles();
 	SearchThreadST::Get()->PerformSearch(data);
 
 	DoSaveSearchPaths();
@@ -228,38 +144,48 @@ SearchData FindInFilesDialog::DoGetSearchData()
 	data.SetMatchCase( (m_data.GetFlags() & wxFRD_MATCHCASE) != 0);
 	data.SetMatchWholeWord((m_data.GetFlags() & wxFRD_MATCHWHOLEWORD) != 0);
 	data.SetRegularExpression((m_data.GetFlags() & wxFRD_REGULAREXPRESSION) != 0);
-	data.SetRootDir(m_dirPicker->GetPath());
 	data.SetUseEditorFontConfig((m_data.GetFlags() & wxFRD_USEFONTENCODING) != 0);
     data.SetDisplayScope((m_data.GetFlags() & wxFRD_DISPLAYSCOPE) != 0);
 
-	if(m_dirPicker->GetPath() == SEARCH_IN_WORKSPACE){
-
-		wxArrayString files;
-		ManagerST::Get()->GetWorkspaceFiles(files);
-		data.SetFiles(files);
-
-	}else if(m_dirPicker->GetPath() == SEARCH_IN_PROJECT){
-
-		wxArrayString files;
-		ManagerST::Get()->GetProjectFiles(ManagerST::Get()->GetActiveProjectName(), files);
-		data.SetFiles(files);
-
-	}else if(m_dirPicker->GetPath() == SEARCH_IN_CURR_FILE_PROJECT){
-
-		wxArrayString files;
-		wxString project = ManagerST::Get()->GetActiveProjectName();
-
-		if (Frame::Get()->GetMainBook()->GetActiveEditor()) {
-			// use the active file's project
-			wxFileName activeFile = Frame::Get()->GetMainBook()->GetActiveEditor()->GetFileName();
-			project = ManagerST::Get()->GetProjectNameByFile(activeFile.GetFullPath());
-		}
-
-		ManagerST::Get()->GetProjectFiles(project, files);
-		data.SetFiles(files);
+	wxArrayString rootDirs;
+	for (size_t i = 0; i < m_listPaths->GetCount(); ++i) {
+		rootDirs.push_back(m_listPaths->GetString(i));
 	}
+	if (rootDirs.IsEmpty()) {
+		wxString dir = m_dirPicker->GetPath();
+		if (dir.IsEmpty() == false) {
+			rootDirs.push_back(dir);
+		}
+	}
+	data.SetRootDirs(rootDirs);
 
-	data.SetOutputTab( m_searchResultsTab->GetSelection() );
+	wxArrayString files;
+	for (size_t i = 0; i < rootDirs.GetCount(); ++i)
+	{
+		const wxString& rootDir = rootDirs.Item(i);
+		if (rootDir == SEARCH_IN_WORKSPACE){
+
+			ManagerST::Get()->GetWorkspaceFiles(files);
+
+		} else if (rootDir == SEARCH_IN_PROJECT){
+
+			ManagerST::Get()->GetProjectFiles(ManagerST::Get()->GetActiveProjectName(), files);
+
+		} else if (rootDir == SEARCH_IN_CURR_FILE_PROJECT){
+
+			wxString project = ManagerST::Get()->GetActiveProjectName();
+
+			if (Frame::Get()->GetMainBook()->GetActiveEditor()) {
+				// use the active file's project
+				wxFileName activeFile = Frame::Get()->GetMainBook()->GetActiveEditor()->GetFileName();
+				project = ManagerST::Get()->GetProjectNameByFile(activeFile.GetFullPath());
+			}
+			ManagerST::Get()->GetProjectFiles(project, files);
+		}
+	}
+	data.SetFiles(files);
+
+	data.UseNewTab(m_resInNewTab->GetValue());
 	data.SetExtensions(m_fileTypes->GetValue());
 	return data;
 }
@@ -268,18 +194,32 @@ void FindInFilesDialog::OnClick(wxCommandEvent &event)
 {
 	wxObject *btnClicked = event.GetEventObject();
 	size_t flags = m_data.GetFlags();
+
+	wxString findWhat = m_findString->GetValue();
+	findWhat = findWhat.Trim().Trim(false);
+
 	m_data.SetFindString( m_findString->GetValue() );
 
 	if(btnClicked == m_stop){
 		SearchThreadST::Get()->StopSearch();
+
 	} else if(btnClicked == m_find){
+		if( findWhat.IsEmpty() ) {
+			return;
+		}
 		DoSearch();
+
 	} else if(btnClicked == m_replaceAll){
+		if( findWhat.IsEmpty() ) {
+			return;
+		}
 		DoSearchReplace();
+
 	} else if(btnClicked == m_cancel){
 		// Hide the dialog
 		DoSaveSearchPaths();
 		Hide();
+
 	} else if(btnClicked == m_matchCase){
 		if(m_matchCase->IsChecked()) {
 			flags |= wxFRD_MATCHCASE;
@@ -310,6 +250,12 @@ void FindInFilesDialog::OnClick(wxCommandEvent &event)
 		} else {
 			flags &= ~(wxFRD_DISPLAYSCOPE);
 		}
+	} else if(btnClicked == m_checkBoxSaveFilesBeforeSearching) {
+		if(m_checkBoxSaveFilesBeforeSearching->IsChecked()) {
+			flags |= wxFRD_SAVE_BEFORE_SEARCH;
+		} else {
+			flags &= ~(wxFRD_SAVE_BEFORE_SEARCH);
+		}
 	}
 
 	// Set the updated flags
@@ -337,6 +283,27 @@ void FindInFilesDialog::OnCharEvent(wxKeyEvent &event)
 	event.Skip();
 }
 
+void FindInFilesDialog::OnAddPath( wxCommandEvent& event )
+{
+	wxString path = m_dirPicker->GetPath();
+	if (m_listPaths->FindString(path) == wxNOT_FOUND) {
+		m_listPaths->Append(path);
+	}
+}
+
+void FindInFilesDialog::OnRemovePath( wxCommandEvent& event )
+{
+	int sel = m_listPaths->GetSelection();
+	if (sel != wxNOT_FOUND) {
+		m_listPaths->Delete(sel);
+	}
+}
+
+void FindInFilesDialog::OnClearPaths( wxCommandEvent& event )
+{
+	m_listPaths->Clear();
+}
+
 bool FindInFilesDialog::Show()
 {
     bool res = IsShown() || wxDialog::Show();
@@ -380,3 +347,10 @@ void FindInFilesDialog::DoSaveSearchPaths()
 
 	m_data.SetSearchPaths(paths);
 }
+
+void FindInFilesDialog::DoSaveOpenFiles()
+{
+	if(m_checkBoxSaveFilesBeforeSearching->IsChecked()){
+		Frame::Get()->GetMainBook()->SaveAll(false, false);
+	}
+}
