@@ -259,6 +259,8 @@ private:
 	void AutoLoadExternalDb();
 	void DoBuildExternalDatabase(const wxString &dir = wxEmptyString);
 
+	void ReloadExternallyModifiedProjectFiles();
+
 protected:
 	//----------------------------------------------------
 	// event handlers
@@ -371,6 +373,7 @@ protected:
 	void OnLoadWelcomePage(wxCommandEvent &event);
 	void OnLoadWelcomePageUI(wxUpdateUIEvent &event);
 	void OnAppActivated(wxActivateEvent &event);
+	void OnReloadExternallModified(wxCommandEvent &e);
 	void OnCompileFile(wxCommandEvent &e);
 	void OnCompileFileUI(wxUpdateUIEvent &e);
 	void OnCloseAllButThis(wxCommandEvent &e);
