@@ -203,6 +203,7 @@ void Manager::DoSetupWorkspace ( const wxString &path )
 		if ( SessionManager::Get().FindSession ( path, session ) ) {
 			SessionManager::Get().SetLastWorkspaceName ( path );
 			Frame::Get()->GetMainBook()->RestoreSession(session);
+			GetBreakpointsMgr()->LoadSession(session);
 		}
 	}
 
@@ -218,12 +219,14 @@ void Manager::CloseWorkspace()
 {
 	m_workspceClosing = true;
 
+	DbgClearWatches();
 	DbgStop();
 
 	//save the current session before closing
 	SessionEntry session;
 	session.SetWorkspaceName ( WorkspaceST::Get()->GetWorkspaceFileName().GetFullPath() );
 	Frame::Get()->GetMainBook()->SaveSession(session);
+	GetBreakpointsMgr()->SaveSession(session);
 	SessionManager::Get().Save ( WorkspaceST::Get()->GetWorkspaceFileName().GetFullPath(), session );
 
 	// since we closed the workspace, we also need to set the 'LastActiveWorkspaceName' to be
@@ -301,7 +304,7 @@ void Manager::CreateProject ( ProjectData &data )
 	WorkspaceST::Get()->AddProjectToBuildMatrix ( proj );
 	ProjectSettingsPtr settings = proj->GetSettings();
 
-	//set the compiler type
+	// set the compiler type
 	ProjectSettingsCookie cookie;
 	BuildConfigPtr bldConf = settings->GetFirstBuildConfiguration ( cookie );
 	while ( bldConf ) {
@@ -310,9 +313,14 @@ void Manager::CreateProject ( ProjectData &data )
 	}
 	proj->SetSettings ( settings );
 
-	//copy the files as they appear in the source project
+	// copy the files as they appear in the source project
 	proj->SetFiles ( data.m_srcProject );
 
+	// copy plugins data
+	std::map<wxString, wxString> pluginsData;
+	data.m_srcProject->GetAllPluginsData( pluginsData );
+	proj->SetAllPluginsData( pluginsData );
+
 	{
 		// copy the actual files from the template directory to the new project path
 		DirSaver ds;
@@ -334,6 +342,15 @@ void Manager::CreateProject ( ProjectData &data )
 
 void Manager::AddProject ( const wxString & path )
 {
+	// create a workspace if there is non
+	if ( IsWorkspaceOpen() == false ) {
+
+		wxFileName fn(path);
+
+		//create a workspace before creating a project
+		CreateWorkspace ( fn.GetName(), fn.GetPath() );
+	}
+
 	wxString errMsg;
 	bool res = WorkspaceST::Get()->AddProject ( path, errMsg );
 	if ( !res ) {
@@ -781,6 +798,31 @@ bool Manager::RemoveFile ( const wxString &fileName, const wxString &vdFullPath
 	return true;
 }
 
+bool Manager::RenameFile(const wxString &origName, const wxString &newName, const wxString &vdFullPath)
+{
+	// remove the file from the workspace (this will erase it from the symbol database and will
+	// also close the editor that it is currently opened in (if any)
+	if (!RemoveFile(origName, vdFullPath))
+		return false;
+
+	// rename the file on filesystem
+	wxRenameFile(origName, newName);
+
+	// readd file to project with the new name
+	wxString projName = vdFullPath.BeforeFirst(wxT(':'));
+	ProjectPtr proj = GetProject(projName);
+	proj->FastAddFile(newName, vdFullPath.AfterFirst(wxT(':')));
+
+	RetagFile(newName);
+
+	// notify of file addition
+	wxArrayString files;
+	files.Add(newName);
+	SendCmdEvent(wxEVT_PROJ_FILE_ADDED, (void*)&files);
+
+	return true;
+}
+
 bool Manager::MoveFileToVD ( const wxString &fileName, const wxString &srcVD, const wxString &targetVD )
 {
 	// to move the file between targets, we need to change the file path, we do this
@@ -793,7 +835,8 @@ bool Manager::MoveFileToVD ( const wxString &fileName, const wxString &srcVD, co
 
 	//set a dir saver point
 	wxFileName fn ( fileName );
-	wxArrayString files(1, fn.GetFullPath());
+	wxArrayString files;
+	files.Add(fn.GetFullPath());
 
 	//remove the file from the source project
 	wxString errMsg;
@@ -901,6 +944,18 @@ void Manager::SetProjectSettings ( const wxString &projectName, ProjectSettingsP
 	proj->SetSettings ( settings );
 }
 
+void Manager::SetProjectGlobalSettings ( const wxString &projectName, BuildConfigCommonPtr settings )
+{
+	wxString errMsg;
+	ProjectPtr proj = WorkspaceST::Get()->FindProjectByName ( projectName, errMsg );
+	if ( !proj ) {
+		wxLogMessage ( errMsg );
+		return;
+	}
+
+	proj->SetGlobalSettings ( settings );
+}
+
 wxString Manager::GetProjectExecutionCommand ( const wxString& projectName, wxString &wd, bool considerPauseWhenExecuting )
 {
 	BuildConfigPtr bldConf = WorkspaceST::Get()->GetProjBuildConf ( projectName, wxEmptyString );
@@ -948,7 +1003,7 @@ wxString Manager::GetProjectExecutionCommand ( const wxString& projectName, wxSt
 		if ( bldConf->GetPauseWhenExecEnds() ) {
 			wxString ld_lib_path;
 			wxFileName exePath ( wxStandardPaths::Get().GetExecutablePath() );
-			wxFileName exeWrapper ( exePath.GetPath(), wxT ( "le_exec.sh" ) );
+			wxFileName exeWrapper ( exePath.GetPath(), wxT ( "codelite_exec" ) );
 
 			if ( wxGetEnv ( wxT ( "LD_LIBRARY_PATH" ), &ld_lib_path ) && ld_lib_path.IsEmpty() == false ) {
 				command << wxT ( "/bin/sh -f " ) << exeWrapper.GetFullPath() << wxT ( " LD_LIBRARY_PATH=" ) << ld_lib_path << wxT ( " " );
@@ -1340,7 +1395,13 @@ void Manager::GetDefaultAcceleratorMap ( MenuItemDataMap& accelMap )
 
 	// append the content of all '*.accelerators' from the plugins
 	// resources table
-	wxDir::GetAllFiles ( GetInstallDir() + wxT ( "/plugins/resources/" ), &files, wxT ( "*.accelerators" ), wxDIR_FILES );
+#ifdef __WXGTK__
+	wxString pluginsDir(PLUGINS_DIR, wxConvUTF8);
+#else
+	wxString pluginsDir(ManagerST::Get()->GetInstallDir() + wxT( "/plugins" ));
+#endif
+
+	wxDir::GetAllFiles ( pluginsDir + wxT ( "/resources/" ), &files, wxT ( "*.accelerators" ), wxDIR_FILES );
 	LoadAcceleratorTable ( files, accelMap );
 }
 
@@ -1360,10 +1421,14 @@ void Manager::DoGetAccelFiles ( wxArrayString& files )
 		//use the default settings
 		fileName = GetStarupDirectory() + wxT ( "/config/accelerators.conf.default" );
 		files.Add ( fileName );
-
+#ifdef __WXGTK__
+		wxString pluginsDir(PLUGINS_DIR, wxConvUTF8);
+#else
+		wxString pluginsDir(ManagerST::Get()->GetInstallDir() + wxT( "/plugins" ));
+#endif
 		// append the content of all '*.accelerators' from the plugins
 		// resources table
-		wxDir::GetAllFiles ( GetInstallDir() + wxT ( "/plugins/resources/" ), &files, wxT ( "*.accelerators" ), wxDIR_FILES );
+		wxDir::GetAllFiles (pluginsDir + wxT ( "/resources/" ), &files, wxT ( "*.accelerators" ), wxDIR_FILES );
 	} else {
 		files.Add ( fileName );
 	}
@@ -1371,6 +1436,7 @@ void Manager::DoGetAccelFiles ( wxArrayString& files )
 
 void Manager::DumpMenu ( wxMenu *menu, const wxString &label, wxString &content )
 {
+#if 0
 	wxMenuItemList items = menu->GetMenuItems();
 	wxMenuItemList::iterator iter = items.begin();
 	for ( ; iter != items.end(); iter++ ) {
@@ -1395,6 +1461,7 @@ void Manager::DumpMenu ( wxMenu *menu, const wxString &label, wxString &content
 		}
 		content << wxT ( "\n" );
 	}
+#endif
 }
 
 
@@ -1772,6 +1839,8 @@ void Manager::DbgStart ( long pid )
 		HideDebuggerPane = true;
 		ShowDebuggerPane ( true );
 	}
+
+	DbgRestoreWatches();
 }
 
 void Manager::DbgStop()
@@ -1787,6 +1856,9 @@ void Manager::DbgStop()
 	// Mark the debugger as non interactive
 	m_dbgCanInteract = false;
 
+	// Keep the current watches for the next debug session
+	m_dbgWatchExpressions = Frame::Get()->GetDebuggerPane()->GetWatchesTable()->GetExpressions();
+
 	//clear the debugger pane
 	Frame::Get()->GetDebuggerPane()->Clear();
 
@@ -1985,13 +2057,14 @@ void Manager::UpdateGotControl ( DebuggerReasons reason )
 		if ( reason == DBG_RECV_SIGNAL_EXC_BAD_ACCESS ) {
 			signame = wxT ( "EXC_BAD_ACCESS" );
 		}
-		DebugMessage ( _ ( "Program Received signal " ) + signame + _ ( "\n" ) );
-		wxMessageBox ( _ ( "Program Received signal " ) + signame + _ ( "\n" ) +
-		               _ ( "Stack trace is available in the 'Stack' tab\n" ),
-		               wxT ( "CodeLite" ), wxICON_ERROR|wxOK );
+		DebugMessage ( _("Program Received signal ") + signame + _("\n") );
+		wxMessageDialog dlg( Frame::Get(), _("Program Received signal ") + signame + wxT("\n") +
+		               _("Stack trace is available in the 'Stack' tab\n"),
+		               wxT("CodeLite"), wxICON_ERROR|wxOK );
+		dlg.ShowModal();
 
 		//Print the stack trace
-		wxAuiPaneInfo &info = Frame::Get()->GetDockingManager().GetPane ( wxT ( "Debugger" ) );
+		wxAuiPaneInfo &info = Frame::Get()->GetDockingManager().GetPane ( wxT("Debugger") );
 		if ( info.IsShown() ) {
 			Frame::Get()->GetDebuggerPane()->SelectTab ( DebuggerPane::FRAMES );
 			UpdateDebuggerPane();
@@ -2028,6 +2101,10 @@ void Manager::UpdateLostControl()
 	DbgUnMarkDebuggerLine();
 	m_dbgCanInteract = false;
 	DebugMessage ( _ ( "Continuing...\n" ) );
+
+	// Reset the debugger call-stack pane
+  Frame::Get()->GetDebuggerPane()->GetFrameListView()->Clear();
+  Frame::Get()->GetDebuggerPane()->GetFrameListView()->SetCurrentLevel(0);
 }
 
 void Manager::UpdateBpAdded(const int internal_id, const int debugger_id)
@@ -2249,13 +2326,17 @@ bool Manager::IsBuildEndedSuccessfully() const
 
 	wxArrayString lines;
 	CompileRequest *cr = dynamic_cast<CompileRequest*> ( m_shellProcess );
-	if ( cr ) {
-		if ( !cr->GetLines ( lines ) ) {
+	CustomBuildRequest *cbr = dynamic_cast<CustomBuildRequest*> ( m_shellProcess );
+	if ( cr || cbr ) {
+		if ( cr && !cr->GetLines ( lines ) ) {
+			return false;
+		}
+		if ( cbr && !cbr->GetLines ( lines ) ) {
 			return false;
 		}
 
 		//check every line to see if we got an error/warning
-		wxString project ( cr->GetProjectName() );
+		wxString project ( cr ? cr->GetProjectName() : cbr->GetProjectName() );
 
 		// TODO :: change the call to ' GetProjBuildConf' to pass the correct
 		// build configuration
@@ -2392,3 +2473,22 @@ void Manager::DoCmdWorkspace ( int cmd )
 		}
 	}
 }
+
+void Manager::DbgClearWatches()
+{
+	m_dbgWatchExpressions.Clear();
+}
+
+
+void Manager::DbgRestoreWatches()
+{
+	// restore any saved watch expressions from previous debug sessions
+	if( m_dbgWatchExpressions.empty() == false ) {
+		for(size_t i=0; i<m_dbgWatchExpressions.GetCount(); i++){
+			DebugMessage(wxT("Restoring watch: ") + m_dbgWatchExpressions.Item(i) + wxT("\n"));
+			wxCommandEvent e(wxEVT_COMMAND_MENU_SELECTED, XRCID("add_watch"));
+			e.SetString(m_dbgWatchExpressions.Item(i));
+			Frame::Get()->GetDebuggerPane()->GetWatchesTable()->AddPendingEvent( e );
+		}
+	}
+}
