@@ -162,6 +162,9 @@ bool BuilderGnuMake::Export(const wxString &project, const wxString &confToBuild
 	wxString buildTool = BuildManagerST::Get()->GetSelectedBuilder()->GetBuildToolCommand(false);
 	buildTool = WorkspaceST::Get()->ExpandVariables(buildTool);
 
+	// fix: replace all Windows like slashes to POSIX
+	buildTool.Replace(wxT("\\"), wxT("/"));
+
 	//generate the makefile for the selected workspace configuration
 	BuildMatrixPtr matrix = WorkspaceST::Get()->GetBuildMatrix();
 	wxString workspaceSelConf = matrix->GetSelectedConfigurationName();
@@ -191,11 +194,46 @@ bool BuilderGnuMake::Export(const wxString &project, const wxString &confToBuild
 			wxFileName fn(dependProj->GetFileName());
 			fn.MakeRelativeTo(wspfile.GetPath());
 
+			bool isPluginGeneratedMakefile = SendCmdEvent(wxEVT_GET_IS_PLUGIN_MAKEFILE, (void*)&depsArr.Item(i), projectSelConf);
+
 			// we handle custom builds and non-custom build separatly:
-			if ( isCustom ) {
+			if ( isPluginGeneratedMakefile ) {
+
+				// this project makefile is generated by a plugin
+				// query the plugin about the build command
+				wxCommandEvent e(wxEVT_GET_PROJECT_BUILD_CMD);
+
+				e.SetClientData( (void*)&depsArr.Item(i) );
+				e.SetString    ( projectSelConf          );
+				wxTheApp->ProcessEvent(e);
+
+				// the result is stored in the 'GetString()'
+				text << wxT("\t") << e.GetString() << wxT("\n");
+
+			} else if ( isCustom ) {
 
 				CreateCustomPreBuildEvents(dependProjbldConf, text);
-				text << wxT("\t") << GetCdCmd(wspfile, fn) << dependProjbldConf->GetCustomBuildCmd() << wxT("\n");
+
+				wxString customWd  = dependProjbldConf->GetCustomBuildWorkingDir();
+				wxString build_cmd = dependProjbldConf->GetCustomBuildCmd();
+				wxString customWdCmd;
+
+				build_cmd.Trim().Trim(false);
+
+				if (build_cmd.empty()) {
+					build_cmd << wxT("@echo Project has no custom build command!");
+				}
+
+				// if a working directory is provided apply it, otherwise use the project
+				// path
+				customWd.Trim().Trim(false);
+				if (customWd.empty() == false ) {
+					customWdCmd << wxT("@cd \"") << ExpandVariables(customWd, dependProj, NULL) << wxT("\" && ");
+				} else {
+					customWdCmd << GetCdCmd(wspfile, fn);
+				}
+
+				text << wxT("\t") << customWdCmd << build_cmd << wxT("\n");
 				CreateCustomPostBuildEvents(dependProjbldConf, text);
 
 			} else {
@@ -229,11 +267,29 @@ bool BuilderGnuMake::Export(const wxString &project, const wxString &confToBuild
 	//make the paths relative
 	wxFileName projectPath(proj->GetFileName());
 	projectPath.MakeRelativeTo(wspfile.GetPath());
-	text << wxT("\t") << GetCdCmd(wspfile, projectPath) << buildTool << wxT(" \"") << proj->GetName() << wxT(".mk\" \n");
+
+	wxString pname( proj->GetName() );
+
+	bool isPluginGeneratedMakefile = SendCmdEvent(wxEVT_GET_IS_PLUGIN_MAKEFILE, (void*)&pname, projectSelConf);
+	if ( isPluginGeneratedMakefile ) {
+
+		wxString cmd;
+		wxCommandEvent e(wxEVT_GET_PROJECT_BUILD_CMD);
+		e.SetClientData((void*)&pname);
+		e.SetString(projectSelConf);
+		wxTheApp->ProcessEvent(e);
+
+		// the build command is in the 'String' member
+		cmd = e.GetString();
+		text << wxT("\t") << cmd << wxT("\n");
+
+	} else {
+		text << wxT("\t") << GetCdCmd(wspfile, projectPath) << buildTool << wxT(" \"") << proj->GetName() << wxT(".mk\" \n");
+	}
 
 	//create the clean target
 	text << wxT("clean:\n");
-	if (!isProjectOnly) {
+	if ( !isProjectOnly ) {
 		for (size_t i=0; i<depsArr.GetCount(); i++) {
 			bool isCustom(false);
 			wxString projectSelConf = matrix->GetProjectSelectedConf(workspaceSelConf, depsArr.Item(i));
@@ -258,10 +314,47 @@ bool BuilderGnuMake::Export(const wxString &project, const wxString &confToBuild
 			}
 
 			// if we are using custom build command, invoke it instead of calling the generated makefile
-			if ( !isCustom ) {
+			wxString pname = dependProj->GetName();
+			bool isPluginGeneratedMakefile = SendCmdEvent(wxEVT_GET_IS_PLUGIN_MAKEFILE, (void*)&pname, projectSelConf);
+
+			// we handle custom builds and non-custom build separatly:
+			if ( isPluginGeneratedMakefile ) {
+
+				// this project makefile is generated by a plugin
+				// query the plugin about the build command
+				wxCommandEvent e( wxEVT_GET_PROJECT_CLEAN_CMD );
+
+				e.SetClientData( (void*)&pname  );
+				e.SetString    ( projectSelConf );
+				wxTheApp->ProcessEvent(e);
+
+				// the result is stored in the 'GetString()'
+				text << wxT("\t") << e.GetString() << wxT("\n");
+
+			} else if ( !isCustom ) {
+
 				text << wxT("\t") << GetCdCmd(wspfile, fn) << buildTool << wxT(" \"") << dependProj->GetName() << wxT(".mk\"  clean\n");
+
 			} else {
-				text << wxT("\t") << GetCdCmd(wspfile, fn) << dependProjbldConf->GetCustomCleanCmd() << wxT("\n");
+
+				wxString customWd = dependProjbldConf->GetCustomBuildWorkingDir();
+				wxString clean_cmd = dependProjbldConf->GetCustomCleanCmd();
+				wxString customWdCmd;
+
+				clean_cmd.Trim().Trim(false);
+				if (clean_cmd.empty()) {
+					clean_cmd << wxT("@echo Project has no custom clean command!");
+				}
+
+				// if a working directory is provided apply it, otherwise use the project
+				// path
+				customWd.Trim().Trim(false);
+				if (customWd.empty() == false ) {
+					customWdCmd << wxT("@cd \"") << ExpandVariables(customWd, dependProj, NULL) << wxT("\" && ");
+				} else {
+					customWdCmd << GetCdCmd(wspfile, fn);
+				}
+				text << wxT("\t") << customWdCmd << clean_cmd << wxT("\n");
 			}
 		}
 	}
@@ -275,9 +368,22 @@ bool BuilderGnuMake::Export(const wxString &project, const wxString &confToBuild
 	}
 
 	text << wxT("\t@echo ") << CLEAN_PROJECT_PREFIX << project << wxT(" - ") << projectSelConf << wxT(" ]----------\n");
+	if ( isPluginGeneratedMakefile ) {
+
+		wxString cmd;
+		wxCommandEvent e(wxEVT_GET_PROJECT_CLEAN_CMD);
+		e.SetClientData((void*)&pname);
+		e.SetString(projectSelConf);
+		wxTheApp->ProcessEvent(e);
+
+		// the build command is in the 'String' member
+		cmd = e.GetString();
+		text << wxT("\t") << cmd << wxT("\n");
+
+	} else {
+		text << wxT("\t") << GetCdCmd(wspfile, projectPath) << buildTool << wxT(" \"") << proj->GetName() << wxT(".mk\" clean\n") ;
+	}
 
-	//make the paths relative
-	text << wxT("\t") << GetCdCmd(wspfile, projectPath) << buildTool << wxT(" \"") << proj->GetName() << wxT(".mk\" clean\n") ;
 	PRINT_TIMESTAMP(wxT("Generating makefile...done\n"));
 
 	//dump the content to file
@@ -292,6 +398,15 @@ bool BuilderGnuMake::Export(const wxString &project, const wxString &confToBuild
 
 void BuilderGnuMake::GenerateMakefile(ProjectPtr proj, const wxString &confToBuild, bool force)
 {
+	wxString pname (proj->GetName());;
+	bool isPluginGeneratedMakefile = SendCmdEvent(wxEVT_GET_IS_PLUGIN_MAKEFILE, (void*)&pname, confToBuild);
+
+	// we handle custom builds and non-custom build separatly:
+	if ( isPluginGeneratedMakefile ) {
+		// nothing to be done here, since the makefile will be generated in the 'wxEVT_CMD_BUILD_STARTING' event
+		return;
+	}
+
 	ProjectSettingsPtr settings = proj->GetSettings();
 	if (!settings) {
 		return;
@@ -445,7 +560,7 @@ void BuilderGnuMake::CreateObjectList(ProjectPtr proj, const wxString &confToBui
 		if (!cmp->GetCmpFileType(files[i].GetExt(), ft))
 			continue;
 
-		if ((OS_WINDOWS) && ft.kind == Compiler::CmpFileKindResource && bldConf && !bldConf->IsResCompilerRequired()) {
+		if (ft.kind == Compiler::CmpFileKindResource && bldConf && !bldConf->IsResCompilerRequired()) {
 			// we are on Windows, the file type is Resource and resource compiler is not required
 			continue;
 		}
@@ -475,10 +590,10 @@ void BuilderGnuMake::CreateFileTargets(ProjectPtr proj, const wxString &confToBu
 	//get the compiler settings
 	CompilerPtr cmp = BuildSettingsConfigST::Get()->GetCompiler(cmpType);
 	bool generateDependeciesFiles = cmp->GetGenerateDependeciesFile() &&
-                                    !cmp->GetDependSuffix().IsEmpty();
-    bool supportPreprocessOnlyFiles = !cmp->GetSwitch(wxT("PreprocessOnly")).IsEmpty() &&
-                                      !cmp->GetPreprocessSuffix().IsEmpty();
-    
+	                                !cmp->GetDependSuffix().IsEmpty();
+	bool supportPreprocessOnlyFiles = !cmp->GetSwitch(wxT("PreprocessOnly")).IsEmpty() &&
+	                                  !cmp->GetPreprocessSuffix().IsEmpty();
+
 	std::vector<wxFileName> abs_files, rel_paths;
 
 	// support for full path
@@ -518,15 +633,15 @@ void BuilderGnuMake::CreateFileTargets(ProjectPtr proj, const wxString &confToBu
 			if (ft.kind == Compiler::CmpFileKindSource) {
 				wxString objectName;
 				wxString dependFile;
-                wxString preprocessedFile;
+				wxString preprocessedFile;
 
 				objectName << wxT("$(IntermediateDirectory)/") << filenameOnly << wxT("$(ObjectSuffix)");
 				if (generateDependeciesFiles) {
 					dependFile << wxT("$(IntermediateDirectory)/") << filenameOnly << wxT("$(DependSuffix)");
 				}
-                if (supportPreprocessOnlyFiles) {
-                    preprocessedFile << wxT("$(IntermediateDirectory)/") << filenameOnly << wxT("$(PreprocessSuffix)");
-                }
+				if (supportPreprocessOnlyFiles) {
+					preprocessedFile << wxT("$(IntermediateDirectory)/") << filenameOnly << wxT("$(PreprocessSuffix)");
+				}
 
 				// set the file rule
 				text << objectName << wxT(": ") << rel_paths.at(i).GetFullPath(wxPATH_UNIX) << wxT(" ") << dependFile << wxT("\n");
@@ -538,14 +653,13 @@ void BuilderGnuMake::CreateFileTargets(ProjectPtr proj, const wxString &confToBu
 					text << wxT("\t") << GetMakeDirCmd(bldConf) << wxT("\n");
 					text << wxT("\t") << wxT("@$(CompilerName) $(CmpOptions) $(IncludePath) -MT") << objectName <<wxT(" -MF") << dependFile << wxT(" -MM \"") << absFileName << wxT("\"\n\n");
 				}
-                if (supportPreprocessOnlyFiles) {
-                    text << preprocessedFile << wxT(": ") << rel_paths.at(i).GetFullPath(wxPATH_UNIX) << wxT("\n");
-                    text << wxT("\t") << GetMakeDirCmd(bldConf) << wxT("\n");
-                    text << wxT("\t") << wxT("$(CompilerName) $(CmpOptions) $(IncludePath) $(PreprocessOnlySwitch) $(OutputSwitch) ") << preprocessedFile << wxT(" \"") << absFileName << wxT("\"\n\n");
-                }
+				if (supportPreprocessOnlyFiles) {
+					text << preprocessedFile << wxT(": ") << rel_paths.at(i).GetFullPath(wxPATH_UNIX) << wxT("\n");
+					text << wxT("\t") << GetMakeDirCmd(bldConf) << wxT("\n");
+					text << wxT("\t") << wxT("$(CompilerName) $(CmpOptions) $(IncludePath) $(PreprocessOnlySwitch) $(OutputSwitch) ") << preprocessedFile << wxT(" \"") << absFileName << wxT("\"\n\n");
+				}
 
-			} else if (ft.kind == Compiler::CmpFileKindResource && bldConf->IsResCompilerRequired() && OS_WINDOWS ) {
-				//Windows only
+			} else if (ft.kind == Compiler::CmpFileKindResource && bldConf->IsResCompilerRequired()) {
 				// we construct an object name which also includes the full name of the reousrce file and appends a .o to the name (to be more
 				// precised, $(ObjectSuffix))
 				wxString objectName;
@@ -576,10 +690,10 @@ void BuilderGnuMake::CreateFileTargets(ProjectPtr proj, const wxString &confToBu
 
 					wxString objectName = abs_files[i].GetName() << wxT("$(ObjectSuffix)");
 					wxString dependFile = abs_files[i].GetName() << wxT("$(DependSuffix)");
-                    wxString preprocessFile = abs_files[i].GetName() << wxT("$(PreprocessSuffix)");
+					wxString preprocessFile = abs_files[i].GetName() << wxT("$(PreprocessSuffix)");
 					text << wxT("\t") << wxT("$(RM) ") << wxT("$(IntermediateDirectory)/") << objectName << wxT("\n");
 					text << wxT("\t") << wxT("$(RM) ") << wxT("$(IntermediateDirectory)/") << dependFile << wxT("\n");
-                    text << wxT("\t") << wxT("$(RM) ") << wxT("$(IntermediateDirectory)/") << preprocessFile << wxT("\n");
+					text << wxT("\t") << wxT("$(RM) ") << wxT("$(IntermediateDirectory)/") << preprocessFile << wxT("\n");
 
 				} else if (ft.kind == Compiler::CmpFileKindResource && bldConf->IsResCompilerRequired()) {
 					wxString ofile = abs_files[i].GetFullName() << wxT("$(ObjectSuffix)");
@@ -605,11 +719,11 @@ void BuilderGnuMake::CreateFileTargets(ProjectPtr proj, const wxString &confToBu
 
 				wxString objectName = abs_files[i].GetName() << wxT("$(ObjectSuffix)");
 				wxString dependFile = abs_files[i].GetName() << wxT("$(DependSuffix)");
-                wxString preprocessFile = abs_files[i].GetName() << wxT("$(PreprocessSuffix)");
+				wxString preprocessFile = abs_files[i].GetName() << wxT("$(PreprocessSuffix)");
 
 				text << wxT("\t") << wxT("$(RM) ") << wxT("$(IntermediateDirectory)/") << objectName << wxT("\n");
 				text << wxT("\t") << wxT("$(RM) ") << wxT("$(IntermediateDirectory)/") << dependFile << wxT("\n");
-                text << wxT("\t") << wxT("$(RM) ") << wxT("$(IntermediateDirectory)/") << preprocessFile << wxT("\n");
+				text << wxT("\t") << wxT("$(RM) ") << wxT("$(IntermediateDirectory)/") << preprocessFile << wxT("\n");
 			}
 		}
 
@@ -746,8 +860,8 @@ void BuilderGnuMake::CreateConfigsVariables(ProjectPtr proj, BuildConfigPtr bldC
 	text << wxT("ArchiveTool :=") << cmp->GetTool(wxT("ArchiveTool")) << wxT("\n");
 	text << wxT("SharedObjectLinkerName :=") << cmp->GetTool(wxT("SharedObjectLinkerName")) << wxT("\n");
 	text << wxT("ObjectSuffix :=") << cmp->GetObjectSuffix() << wxT("\n");
-    text << wxT("DependSuffix :=") << cmp->GetDependSuffix() << wxT("\n");
-    text << wxT("PreprocessSuffix :=") << cmp->GetPreprocessSuffix() << wxT("\n");
+	text << wxT("DependSuffix :=") << cmp->GetDependSuffix() << wxT("\n");
+	text << wxT("PreprocessSuffix :=") << cmp->GetPreprocessSuffix() << wxT("\n");
 	text << wxT("DebugSwitch :=") << cmp->GetSwitch(wxT("Debug")) << wxT("\n");
 	text << wxT("IncludeSwitch :=") << cmp->GetSwitch(wxT("Include")) << wxT("\n");
 	text << wxT("LibrarySwitch :=") << cmp->GetSwitch(wxT("Library")) << wxT("\n");
@@ -761,8 +875,8 @@ void BuilderGnuMake::CreateConfigsVariables(ProjectPtr proj, BuildConfigPtr bldC
 	text << wxT("Preprocessors :=") << ParsePreprocessor(bldConf->GetPreprocessor()) << wxT("\n");
 	text << wxT("ObjectSwitch :=") << cmp->GetSwitch(wxT("Object")) << wxT("\n");
 	text << wxT("ArchiveOutputSwitch :=") << cmp->GetSwitch(wxT("ArchiveOutput")) << wxT("\n");
-    text << wxT("PreprocessOnlySwitch :=") << cmp->GetSwitch(wxT("PreprocessOnly")) << wxT("\n");
-    
+	text << wxT("PreprocessOnlySwitch :=") << cmp->GetSwitch(wxT("PreprocessOnly")) << wxT("\n");
+
 	wxString buildOpts = bldConf->GetCompileOptions();
 	buildOpts.Replace(wxT(";"), wxT(" "));
 	text << wxT("CmpOptions :=") << buildOpts << wxT(" $(Preprocessors)") << wxT("\n");
@@ -797,7 +911,7 @@ wxString BuilderGnuMake::ParseIncludePath(const wxString &paths, const wxString
 	//convert semi-colon delimited string into GNU list of
 	//include paths:
 	wxString incluedPath(wxEmptyString);
-	wxStringTokenizer tkz(paths, wxT(";"));
+	wxStringTokenizer tkz(paths, wxT(";"), wxTOKEN_STRTOK);
 	//prepend each include path with -I
 	while (tkz.HasMoreTokens()) {
 		wxString path(tkz.NextToken());
@@ -814,7 +928,7 @@ wxString BuilderGnuMake::ParseLibPath(const wxString &paths, const wxString &pro
 	//convert semi-colon delimited string into GNU list of
 	//lib path
 	wxString libPath(wxEmptyString);
-	wxStringTokenizer tkz(paths, wxT(";"));
+	wxStringTokenizer tkz(paths, wxT(";"), wxTOKEN_STRTOK);
 	//prepend each include path with libpath switch
 	while (tkz.HasMoreTokens()) {
 		wxString path(tkz.NextToken());
@@ -829,7 +943,7 @@ wxString BuilderGnuMake::ParseLibPath(const wxString &paths, const wxString &pro
 wxString BuilderGnuMake::ParsePreprocessor(const wxString &prep)
 {
 	wxString preprocessor(wxEmptyString);
-	wxStringTokenizer tkz(prep, wxT(";"));
+	wxStringTokenizer tkz(prep, wxT(";"), wxTOKEN_STRTOK);
 	//prepend each include path with libpath switch
 	while (tkz.HasMoreTokens()) {
 		wxString p(tkz.NextToken());
@@ -844,7 +958,7 @@ wxString BuilderGnuMake::ParseLibs(const wxString &libs)
 	//convert semi-colon delimited string into GNU list of
 	//libs
 	wxString slibs(wxEmptyString);
-	wxStringTokenizer tkz(libs, wxT(";"));
+	wxStringTokenizer tkz(libs, wxT(";"), wxTOKEN_STRTOK);
 	//prepend each include path with -l and strip trailing lib string
 	//also, if the file contains an extension (.a, .so, .dynlib) remove them as well
 	while (tkz.HasMoreTokens()) {
@@ -884,6 +998,9 @@ wxString BuilderGnuMake::GetBuildCommand(const wxString &project, const wxString
 	wxString buildTool = BuildManagerST::Get()->GetSelectedBuilder()->GetBuildToolCommand(true);
 	buildTool = WorkspaceST::Get()->ExpandVariables(buildTool);
 
+	// fix: replace all Windows like slashes to POSIX
+	buildTool.Replace(wxT("\\"), wxT("/"));
+
 	wxString type = Builder::NormalizeConfigName(matrix->GetSelectedConfigurationName());
 	cmd << buildTool << wxT(" \"") << WorkspaceST::Get()->GetName() << wxT("_wsp.mk\"");
 	return cmd;
@@ -903,6 +1020,9 @@ wxString BuilderGnuMake::GetCleanCommand(const wxString &project, const wxString
 	wxString buildTool = BuildManagerST::Get()->GetSelectedBuilder()->GetBuildToolCommand(true);
 	buildTool = WorkspaceST::Get()->ExpandVariables(buildTool);
 
+	// fix: replace all Windows like slashes to POSIX
+	buildTool.Replace(wxT("\\"), wxT("/"));
+
 	BuildMatrixPtr matrix = WorkspaceST::Get()->GetBuildMatrix();
 	wxString type = Builder::NormalizeConfigName(matrix->GetSelectedConfigurationName());
 	cmd << buildTool << wxT(" \"") << WorkspaceST::Get()->GetName() << wxT("_wsp.mk\" clean");
@@ -924,12 +1044,9 @@ wxString BuilderGnuMake::GetPOBuildCommand(const wxString &project, const wxStri
 	wxString buildTool = BuildManagerST::Get()->GetSelectedBuilder()->GetBuildToolCommand(true);
 	buildTool = WorkspaceST::Get()->ExpandVariables(buildTool);
 
-	wxString type = matrix->GetProjectSelectedConf(matrix->GetSelectedConfigurationName(), project);
-	if (confToBuild.IsEmpty() == false) {
-		// incase we use to generate a 'Project Only' makefile,
-		// we allow the caller to override the selected configuration with 'confToBuild' parameter
-		type = confToBuild;
-	}
+	// fix: replace all Windows like slashes to POSIX
+	buildTool.Replace(wxT("\\"), wxT("/"));
+
 	//cd to the project directory
 	cmd << buildTool << wxT(" \"") << project << wxT(".mk\"") ;
 	return cmd;
@@ -948,14 +1065,11 @@ wxString BuilderGnuMake::GetPOCleanCommand(const wxString &project, const wxStri
 
 	BuildMatrixPtr matrix = WorkspaceST::Get()->GetBuildMatrix();
 	wxString buildTool = BuildManagerST::Get()->GetSelectedBuilder()->GetBuildToolCommand(true);
+
+	// fix: replace all Windows like slashes to POSIX
+	buildTool.Replace(wxT("\\"), wxT("/"));
 	buildTool = WorkspaceST::Get()->ExpandVariables(buildTool);
 
-	wxString type = matrix->GetProjectSelectedConf(matrix->GetSelectedConfigurationName(), project);
-	if (confToBuild.IsEmpty() == false) {
-		// incase we use to generate a 'Project Only' makefile,
-		// we allow the caller to override the selected configuration with 'confToBuild' parameter
-		type = confToBuild;
-	}
 	//cd to the project directory
 	cmd << buildTool << wxT(" \"") << project << wxT(".mk\" clean");
 	return cmd;
@@ -974,7 +1088,9 @@ wxString BuilderGnuMake::GetSingleFileCmd(const wxString &project, const wxStrin
 
 	BuildMatrixPtr matrix = WorkspaceST::Get()->GetBuildMatrix();
 	wxString buildTool = BuildManagerST::Get()->GetSelectedBuilder()->GetBuildToolCommand(true);
-	wxString type = matrix->GetProjectSelectedConf(matrix->GetSelectedConfigurationName(), project);
+
+	// fix: replace all Windows like slashes to POSIX
+	buildTool.Replace(wxT("\\"), wxT("/"));
 
 	//create the target
 	wxString tareget;
@@ -989,11 +1105,11 @@ wxString BuilderGnuMake::GetSingleFileCmd(const wxString &project, const wxStrin
 
 	return EnvironmentConfig::Instance()->ExpandVariables(cmd);
 }
- 
+
 wxString BuilderGnuMake::GetPreprocessFileCmd(const wxString &project, const wxString &confToBuild, const wxString &fileName, wxString &errMsg)
 {
-    // TODO: factor out common code with GetSingleFileCmd()
-    
+	// TODO: factor out common code with GetSingleFileCmd()
+
 	wxString cmd;
 	BuildConfigPtr bldConf = WorkspaceST::Get()->GetProjBuildConf(project, confToBuild);
 	if (!bldConf) {
@@ -1007,6 +1123,9 @@ wxString BuilderGnuMake::GetPreprocessFileCmd(const wxString &project, const wxS
 	wxString buildTool = BuildManagerST::Get()->GetSelectedBuilder()->GetBuildToolCommand(true);
 	wxString type = matrix->GetProjectSelectedConf(matrix->GetSelectedConfigurationName(), project);
 
+	// fix: replace all Windows like slashes to POSIX
+	buildTool.Replace(wxT("\\"), wxT("/"));
+
 	//create the target
 	wxString tareget;
 	wxString objSuffix;
@@ -1020,7 +1139,7 @@ wxString BuilderGnuMake::GetPreprocessFileCmd(const wxString &project, const wxS
 
 	return EnvironmentConfig::Instance()->ExpandVariables(cmd);
 }
- 
+
 wxString BuilderGnuMake::GetCdCmd(const wxFileName &path1, const wxFileName &path2)
 {
 	wxString cd_cmd(wxT("@"));
