@@ -1,30 +1,31 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 //
-// copyright            : (C) 2008 by Eran Ifrah                            
-// file name            : sessionmanager.h              
-//                                                                          
+// copyright            : (C) 2008 by Eran Ifrah
+// file name            : sessionmanager.h
+//
 // -------------------------------------------------------------------------
-// A                                                                        
-//              _____           _      _     _ _                            
-//             /  __ \         | |    | |   (_) |                           
-//             | /  \/ ___   __| | ___| |    _| |_ ___                      
-//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )                     
-//             | \__/\ (_) | (_| |  __/ |___| | ||  __/                     
-//              \____/\___/ \__,_|\___\_____/_|\__\___|                     
-//                                                                          
-//                                                  F i l e                 
-//                                                                          
-//    This program is free software; you can redistribute it and/or modify  
-//    it under the terms of the GNU General Public License as published by  
-//    the Free Software Foundation; either version 2 of the License, or     
-//    (at your option) any later version.                                   
-//                                                                          
+// A
+//              _____           _      _     _ _
+//             /  __ \         | |    | |   (_) |
+//             | /  \/ ___   __| | ___| |    _| |_ ___
+//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )
+//             | \__/\ (_) | (_| |  __/ |___| | ||  __/
+//              \____/\___/ \__,_|\___\_____/_|\__\___|
+//
+//                                                  F i l e
+//
+//    This program is free software; you can redistribute it and/or modify
+//    it under the terms of the GNU General Public License as published by
+//    the Free Software Foundation; either version 2 of the License, or
+//    (at your option) any later version.
+//
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
  #ifndef SESSIONMANAGER_H
 #define SESSIONMANAGER_H
 
+#include "debugger.h"
 #include "serialized_object.h"
 #include "wx/xml/xml.h"
 #include <vector>
@@ -40,6 +41,7 @@ class SessionEntry : public SerializedObject {
 	wxArrayString m_tabs;
 	wxString m_workspaceName;
 	std::vector<TabInfo> m_vTabInfoArr;
+	BreakpointInfoArray m_breakpoints;
 
 public:
 	//Setters
@@ -47,13 +49,15 @@ public:
 	//void SetTabs(const wxArrayString& tabs) {this->m_tabs = tabs;}
 	void SetWorkspaceName(const wxString& workspaceName) {this->m_workspaceName = workspaceName;}
 	void SetTabInfoArr(const std::vector<TabInfo>& _vTabInfoArr) {m_vTabInfoArr = _vTabInfoArr;}
-	
+	void SetBreakpoints(const std::vector<BreakpointInfo>& breakpoints) {m_breakpoints.SetBreakpoints(breakpoints);}
+
 	//Getters
 	const int& GetSelectedTab() const {return m_selectedTab;}
 	//const wxArrayString& GetTabs() const {return m_tabs;}
 	const wxString& GetWorkspaceName() const {return m_workspaceName;}
 	const std::vector<TabInfo>& GetTabInfoArr() {return m_vTabInfoArr;}
-	
+	const std::vector<BreakpointInfo>& GetBreakpoints() const {return m_breakpoints.GetBreakpoints();}
+
 	SessionEntry();
 	virtual ~SessionEntry();
 
@@ -64,14 +68,14 @@ public:
 
 /**
  * \class SessionManager
- * \brief 
+ * \brief
  * \author Eran
  * \date 09/25/07
  */
 class SessionManager {
 	wxXmlDocument m_doc;
 	wxFileName m_fileName;
-	
+
 private:
 	SessionManager();
 	~SessionManager();
@@ -83,6 +87,9 @@ public:
 	bool FindSession(const wxString &name, SessionEntry &session);
 	void SetLastWorkspaceName(const wxString &name);
 	wxString GetLastSession();
+
+private:
+	wxFileName GetSessionFileName(const wxString& name) const;
 };
 
 #endif //SESSIONMANAGER_H
