@@ -24,6 +24,7 @@
 //////////////////////////////////////////////////////////////////////////////
 #include "updatepostcmdaction.h"
 #include "applypatchpostcmdaction.h"
+#include "revertpostcmdaction.h"
 #include "svnreportgeneratoraction.h"
 #include "custom_tab.h"
 #include "svntab.h"
@@ -208,12 +209,11 @@ SubversionPlugin::SubversionPlugin(IManager *manager)
 		FolderConflictIconId 		= tree->GetImageList()->Add(wxXmlResource::Get()->LoadBitmap(wxT("folder_conflict")));
 
 		// wxFormBuilder support
-		wxString basePath(m_mgr->GetInstallDirectory() + wxT("/plugins/resources/"));
 		wxBitmap wxfb_ok, wxfb_modified, wxfb_conflict;
 
-		wxfb_ok.LoadFile(basePath + wxT("wxfb_ok.png"), wxBITMAP_TYPE_PNG);
-		wxfb_modified.LoadFile(basePath + wxT("wxfb_modified.png"), wxBITMAP_TYPE_PNG);
-		wxfb_conflict.LoadFile(basePath + wxT("wxfb_conflict.png"), wxBITMAP_TYPE_PNG);
+		wxfb_ok       = LoadBitmapFile(wxT("wxfb_ok.png"));
+		wxfb_modified = LoadBitmapFile(wxT("wxfb_modified.png"));
+		wxfb_conflict = LoadBitmapFile(wxT("wxfb_conflict.png"));
 
 		wxFBConflictIconId = tree->GetImageList()->Add(wxfb_conflict);
 		wxFBOkIconId = tree->GetImageList()->Add(wxfb_ok);
@@ -307,7 +307,6 @@ wxMenu *SubversionPlugin::CreatePopMenu()
 SubversionPlugin::~SubversionPlugin()
 {
 	SvnCommitMsgsMgr::Release();
-	UnPlug();
 }
 
 void SubversionPlugin::OnSvnAbort(wxCommandEvent &event)
@@ -438,7 +437,7 @@ void SubversionPlugin::OnRevertFile(wxCommandEvent &e)
 	wxUnusedVar(e);
 	IEditor *editor = m_mgr->GetActiveEditor();
 	if (editor) {
-		m_svn->RevertFile(editor->GetFileName());
+		m_svn->RevertFile(editor->GetFileName(), new RevertPostCmdAction(m_mgr));
 	}
 }
 
