@@ -378,7 +378,7 @@ void UnitTestPP::OnProcessTerminated(wxProcessEvent& e)
 
 	// parse the results
 	TestSummary summary;
-	parser.Parse(summary);
+	parser.Parse( &summary );
 
 	// create new report page, and add it to the editor
 	static int counter(1);
@@ -387,7 +387,7 @@ void UnitTestPP::OnProcessTerminated(wxProcessEvent& e)
 		return;
 	}
 
-	UnitTestsPage *page = new UnitTestsPage(m_mgr->GetDockingManager()->GetManagedWindow(), summary, m_mgr);
+	UnitTestsPage *page = new UnitTestsPage(m_mgr->GetDockingManager()->GetManagedWindow(), &summary, m_mgr);
 	m_mgr->AddPage(page, wxString::Format(wxT("UnitTest++ Report <%d>"), counter), wxNullBitmap, true);
 	counter++;
 
